@@ -6,7 +6,6 @@ mod terminal;
 pub use list::*;
 pub use terminal::*;
 
-use std::iter::repeat;
 use tui::{self, buffer::Buffer, layout::Rect, style::Color, style::Style};
 use unicode_segmentation::UnicodeSegmentation;
 use unicode_width::UnicodeWidthStr;
@@ -15,7 +14,7 @@ pub fn fill_background_to_right(mut s: String, entire_width: u16) -> String {
     match (s.len(), entire_width as usize) {
         (x, y) if x >= y => s,
         (x, y) => {
-            s.extend(repeat(' ').take(y - x));
+            s.extend(std::iter::repeat_n(' ', y - x));
             s
         }
     }
@@ -52,7 +51,7 @@ pub fn draw_text_with_ellipsis_nowrap(
             if x + 1 == bound.right() {
                 ellipsis_candidate_x = Some(x);
             }
-            cell.set_symbol(g.into());
+            cell.set_symbol(g);
             if let Some(s) = s {
                 cell.set_style(s);
             }
@@ -68,7 +67,7 @@ pub fn draw_text_with_ellipsis_nowrap(
             }
         }
         if let (Some(_), Some(x)) = (graphemes.next(), ellipsis_candidate_x) {
-            buf.get_mut(x, bound.y).set_symbol("…".into());
+            buf.get_mut(x, bound.y).set_symbol("…");
         }
     }
     total_width as u16
@@ -85,7 +84,7 @@ pub fn draw_text_nowrap_fn(
     }
     for (g, x) in t.as_ref().graphemes(true).zip(bound.left()..bound.right()) {
         let cell = buf.get_mut(x, bound.y);
-        cell.set_symbol(g.into());
+        cell.set_symbol(g);
         cell.set_style(s(cell.symbol(), x, bound.y));
     }
 }
