@@ -14,7 +14,7 @@ pub struct List {
 impl List {
     fn list_offset_for(&self, entry_in_view: Option<usize>, height: usize) -> usize {
         match entry_in_view {
-            Some(pos) => match height as usize {
+            Some(pos) => match height {
                 h if (self.offset + h).saturating_sub(1) < pos => pos - h + 1,
                 _ if self.offset > pos => pos,
                 _ => self.offset,
